<div id="scores-list-panel" data-panels-layout-tab-content-id="scores"
  class="panels-layout-tab-content thread-comments-panel panels-layout-container panels-layout-vertical panels-layout-wrapper">
  <div class="panels-layout-content panels-layout-scrollable">
    <div class="panels-layout-container container padded">
      <div id="scores-list-container" class="scores-list-container">
        <!-- Scores list placehodler -->
        <div id="temp-loader-splash" class="loader-splash"><div class="loader-spinner"></div></div>
      </div>
    </div>
  </div>
</div>
