interface TThreadCommentsInitParams {
  handlers: TSharedHandlers;
  events: SimpleEvents;
  threadCommentsRender: ThreadCommentsRender;
  threadCommentsNodes: ThreadCommentsNodes;
  threadCommentsStates: ThreadCommentsStates;
  threadCommentsHandlers: ThreadCommentsHandlers;
  threadCommentsPrepare: ThreadCommentsPrepare;
}
