// @ts-check

/** Api base
 * eg: 'http://localhost:5000/scores/get/{id}'
 */
export const scoresApiUrlPrefix = '/scores/get/';

/** Use exponential numbers format? Specify the number of fractional digits.
 * @type {number | undefined}
 */
export const fractionDigits = 2;
