<div id="recent-processes-list-panel" class="panels-layout-side panels-layout-container panels-layout-right recent-processes-list-panel hidden">
  <div class="panels-layout-content panels-layout-scrollable">
    <div class="panels-layout-container container padded">
      <div id="recent-processes-container" class="recent-processes-container">
        <!-- Recent processes placehodler -->
        <div id="temp-loader-splash" class="loader-splash"><div class="loader-spinner"></div></div>
      </div>
    </div>
  </div>
</div>
