<div id="thread-comments-panel" data-panels-layout-tab-content-id="comments"
  class="panels-layout-tab-content thread-comments-panel panels-layout-container panels-layout-vertical panels-layout-wrapper">
  <div id="thread-comments-panel-toolbar" class="thread-comments-panel-toolbar-wrapper">
    <div class="thread-comments-toolbar">
      <a
        id="expandAllThreads"
        title="Collapse/expand threads"
        class="toolbar-icon"
        onClick="processDetailPage.callbacks.expandAllThreads(this)"
      >
        <i class="fa fa-expand"></i>
      </a>
      <a
        id="addNewThread"
        title="Add new thread"
        class="toolbar-icon"
        onClick="processDetailPage.callbacks.addNewThread(this)"
      >
        <i class="fa fa-plus"></i>
      </a>
      <div class="group">
        <label for="threadsSortMode">Sort by:</label>
        <select
          id="threadsSortMode"
          onChange="processDetailPage.callbacks.setSortMode(this)"
        >
          <option value="resolved|modifiedDate" selected>Resolved / Modified date</option>
          <option value="resolved|name">Resolved / Name</option>
        </select>
      </div>
    </div>
  </div>
  <div class="panels-layout-content panels-layout-scrollable">
    <div class="panels-layout-container container padded">
      <div id="thread-comments" class="thread-comments">
        <!-- Thread comments placehodler -->
        <div id="temp-loader-splash" class="loader-splash"><div class="loader-spinner"></div></div>
      </div>
    </div>
  </div>
</div>
