interface TScoresDataItem {
  category: string; // 'global warming potential (GWP100)'
  original: number; // 0.5596522857406839
  ratio: number; // 0.29588779682710437
  relinked: number; // 1.891434157616526
  unit: string; // 'UBP'
}
type TScoresList = TScoresDataItem[];
