// @ts-check

export const RecentProcessesListData = {
  // Data...
  /** @type {TRecentProcesses} */
  recentProcesses: [],

  // Common params...
  error: undefined,
  isError: false,
  isLoading: true,
  hasData: false,
};
